﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2011 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Windows.Forms;
using HeuristicLab.MainForm;
using HeuristicLab.MainForm.WindowsForms;

namespace HeuristicLab.Analysis.Views {
  [View("DataRow Visual Properties")]
  public partial class DataTableVisualPropertiesControl : UserControl {
    protected bool SuppressEvents { get; set; }

    private DataTableVisualProperties content;
    public DataTableVisualProperties Content {
      get { return content; }
      set {
        bool changed = (value != content);
        content = value;
        if (changed) OnContentChanged();
      }
    }

    public DataTableVisualPropertiesControl() {
      InitializeComponent();
    }

    protected virtual void OnContentChanged() {
      SuppressEvents = true;
      try {
        if (Content == null) {
          yPrimaryTextBox.Text = string.Empty;
          ySecondaryTextBox.Text = string.Empty;
          xPrimaryTextBox.Text = string.Empty;
          xSecondaryTextBox.Text = string.Empty;
        } else {
          yPrimaryTextBox.Text = Content.YAxisTitle;
          ySecondaryTextBox.Text = Content.SecondYAxisTitle;
          xPrimaryTextBox.Text = Content.XAxisTitle;
          xSecondaryTextBox.Text = Content.SecondXAxisTitle;
        }
      } finally { SuppressEvents = false; }
      SetEnabledStateOfControls();
    }

    protected virtual void SetEnabledStateOfControls() {
      axisTitlesGroupBox.Enabled = Content != null;
    }

    #region Event Handlers
    private void yPrimaryTextBox_Validated(object sender, System.EventArgs e) {
      if (!SuppressEvents && Content != null) {
        Content.YAxisTitle = yPrimaryTextBox.Text;
      }
    }

    private void ySecondaryTextBox_Validated(object sender, System.EventArgs e) {
      if (!SuppressEvents && Content != null) {
        Content.SecondYAxisTitle = ySecondaryTextBox.Text;
      }
    }

    private void xPrimaryTextBox_Validated(object sender, System.EventArgs e) {
      if (!SuppressEvents && Content != null) {
        Content.XAxisTitle = xPrimaryTextBox.Text;
      }
    }

    private void xSecondaryTextBox_Validated(object sender, System.EventArgs e) {
      if (!SuppressEvents && Content != null) {
        Content.SecondXAxisTitle = xSecondaryTextBox.Text;
      }
    }
    #endregion
  }
}
